Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(40)

Unified Diff: runtime/vm/flow_graph_allocator.cc

Issue 2994113003: [vm] Rename *MintOp to *Int64Op to emphasis that they operate on unboxed values. (Closed)
Patch Set: il-printer Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/flow_graph.cc ('k') | runtime/vm/flow_graph_compiler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_allocator.cc
diff --git a/runtime/vm/flow_graph_allocator.cc b/runtime/vm/flow_graph_allocator.cc
index e70a5b781eec4f1a248a02ceca48921dbac1fdbe..30f1dd6ab1a8df29debb73bba3eba7d932ad8ead 100644
--- a/runtime/vm/flow_graph_allocator.cc
+++ b/runtime/vm/flow_graph_allocator.cc
@@ -2848,8 +2848,8 @@ void FlowGraphAllocator::ResolveControlFlow() {
}
static Representation RepresentationForRange(Representation definition_rep) {
- if (definition_rep == kUnboxedMint) {
- // kUnboxedMint is split into two ranges, each of which are kUntagged.
+ if (definition_rep == kUnboxedInt64) {
+ // kUnboxedInt64 is split into two ranges, each of which are kUntagged.
return kUntagged;
} else if (definition_rep == kUnboxedUint32) {
// kUnboxedUint32 is untagged.
« no previous file with comments | « runtime/vm/flow_graph.cc ('k') | runtime/vm/flow_graph_compiler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698